%
% File name:  MicroGird_Dispatch.m
% Contains:   The main power dispatch function

clear;
clc;          
close all;    % closing all figures
tic;  % Time counting start
% Variables for PSO
nvars = 6; %Number of variables for PSO
% Beneficial of this code can write their own cost function.
% This cost function "Cost_dispatch" is not provided with this dataset.
fun = @Cost_dispatch;  % Cost function
options = optimoptions('particleswarm','Display','off');

%        I   II  III   IV  V
%        MT1 MT2 MT3   FC  Actul load intervals
ub    = [66  66  66    40  0 0];  % Upper bounds of variables
lb    = [ 0  0    0     0  0 0];  % lower bound of variables

% Gas dispatch
%[gas_mt_max, gas_required_heat_load] = Gas_dispatch(ub(1),0,0);
% Micro Gird parameters
PL_factor               = 250; % kWh or MWh
Wind_turbine_capacity   =  50; % wind turbine installed capacity kWh or MWh
Solar_power_capacity    = 100; % Solar power installed capacity  kWh or MWh

%
%-----------------Electric power load trend-----------------%
PL_unit = [0.736 0.694 0.670 0.657 0.664 0.706 0.773 0.829 0.871 0.898 0.919 0.935 0.953 0.971 0.983 0.993 1.000 0.994 0.979 0.953 0.940 0.910 0.844 0.773];
PL=PL_factor*PL_unit;
%-----------------Wind power-----------------%
% Wind speed
V = [7.20,6.40,6.30,4.70,2.80,3.10,5.30,4.80,4.60,7.60,8.30,8.30,9.70,8.60,10.10,9.20,7.90,8.20,7.60,4.80,5.20,5.50,7.40,5.80];
WT=Wind_turbine_capacity*Pwt(V);   % 24 hours wind turbine  maximum power tracking matrix
%-----------------Solar power-----------------%
sun = [0;0;0;0;0;140;325;545;785;820;960;1000;960;870;700;540;320;140;0;0;0;0;0;0];% Light intensity
T   = zeros(size(sun));
T(:)= 25; % temperature
v   = 0.05;
PV=(Solar_power_capacity/10)*PandO(sun,v,T);     % 24 hours PV maximum power tracking
PV_WT=PV+WT';
%----------------- Gird dispatch info-----------------
intervals     = size(PL,2);
Grid_dispatch = zeros(nvars, intervals);
%
actual_load = PL - PV_WT';
%% Calling PSO
for i = 1:intervals
    ub    = [66  66  66 40  actual_load(i) i];
    lb    = [ 0  0    0  0  actual_load(i) i];
    [x,fval,exitflag] = particleswarm(fun,nvars,lb,ub,options);
    Grid_dispatch(:,i) = x;
end
%% Energy storage system (Battery bank)
Main_Grid = actual_load - (Grid_dispatch(1,:)+ Grid_dispatch(2,:));
[bat, b_grid] = Bat( Main_Grid );

%%      
Dispatch_all      = zeros(9,intervals);
Dispatch_all(1,:) = PV';
Dispatch_all(2,:) = WT;
Dispatch_all(3,:) = Grid_dispatch(1,:);
Dispatch_all(4,:) = Grid_dispatch(2,:);
Dispatch_all(5,:) = Grid_dispatch(3,:);
Dispatch_all(6,:) = Grid_dispatch(4,:);
Dispatch_all(7,:) = Main_Grid;
Dispatch_all(8,:) = bat;
Dispatch_all(9,:) = PL;

Dispatch_all      = round(Dispatch_all,3);
% I   II  III  IV   V     VI  VII    VIII     IX
% PV  WT  MT1  MT2  MT3   FC  Grid   Battery  Load

%%        Ploting results    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure('Name','Grid Price');
Grid_price= [0.17 0.17 0.17 0.17 0.17 0.17 0.17 0.49 0.49 0.49 0.83 ...
              0.83 0.83 0.83 0.83 0.49 0.49 0.49 0.83 0.83 0.83 0.49 ...
              0.49 0.17];
stairs(Grid_price,'LineWidth',2,'Color',[0 1 0]);        % Main grid price
xlabel('Time (h)','FontWeight','bold','FontName','times new roman');
ylabel('Electric power flow (MW)','FontWeight','bold','FontName','times new roman');
ylim([0 1]);
set(gca,'FontName','times new roman','FontSize',14,'FontWeight','bold',...
    'LineWidth',2,'XTick',[0 3 6 9 12 15 18 21 24]);
legend('Main Grid Price','Location','northwest');
box on;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure('Name','Renewable Generation');
hold on;
stairs(PV','LineWidth',2);    % PV 
stairs(WT ,'LineWidth',2);    % Wind turbine power
hold off;
xlabel('Time (h)','FontWeight','bold','FontName','times new roman');
ylabel('Electric power flow (MW)','FontWeight','bold','FontName','times new roman');
set(gca,'FontName','times new roman','FontSize',14,'FontWeight','bold', ...
    'LineWidth',2,'XTick',[0 3 6 9 12 15 18 21 24]);
legend('PV','WT','Location','northwest');
box on;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure('Name','Main Grid and Load');
hold on;
stairs(Dispatch_all(9,:),'LineWidth',2,'Color',[1 0 0]);  % Microgird Load
stairs(Dispatch_all(7,:),'LineWidth',2,'Color',[1 0 1]);  % Main Grid
hold off;
xlabel('Time (h)','FontWeight','bold','FontName','times new roman');
ylabel('Electric power flow (MW)','FontWeight','bold','FontName','times new roman');
set(gca,'FontName','times new roman','FontSize',14,'FontWeight','bold',...
    'LineWidth',2,'XTick',[0 3 6 9 12 15 18 21 24]);
legend('Load','Main Grid','Location','northwest');
box on;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure('Name','Microgrid Dispatch');
hold on;
stairs(PV'+WT           ,'LineWidth',2,'Color',[0 1 0]);       % PV + Wind turbine power
bar(Dispatch_all(8,:)   ,'LineWidth',2,'FaceColor',[0.5 0.7 0.2],...
    'EdgeColor',[0.5 0.7 0.2],'BarWidth',1);                   % Battery
stairs(Dispatch_all(3,:),'LineWidth',2,'Color',[1 0 0]);       % Micro Gas turbine 1
stairs(Dispatch_all(4,:),'LineWidth',2,'Color',[1 0 1]);       % Micro Gas turbine 2
stairs(Dispatch_all(5,:),'LineWidth',2,'Color',[0.6 0.4 0.4]); % Micro Gas turbine 3
stairs(Dispatch_all(6,:),'LineWidth',2,'Color',[0 0 1]);       % Fuel cell
hold off;
xlabel('Time (h)','FontWeight','bold','FontName','times new roman');
ylabel('Electric power flow (MW)','FontWeight','bold','FontName','times new roman');
set(gca,'FontName','times new roman','FontSize',14,'FontWeight','bold',....
    'LineWidth',2,'XTick',[0 3 6 9 12 15 18 21 24]);
legend('PV +WT','Battery','MT1','MT2','MT3','Fuel Cell','Location','northwest');
box on;

%%             A Microgrids one-day cost calculator
save('New_Dispatch_all.mat','Dispatch_all');
Cost_calculator