%
% File name:  max60.m
% Contains:   Current generated by solar PV

function I=max60(u,sun,T)
S=54*55;           %% Solar panel area
Voc=3.5;           %% Open circuit voltage
Isc=0.03*S/100;    %% Short circuit current
Vm=2.6;            %% The voltage at the maximum power point of the battery
Im=0.8;            %% The current at the maximum power point of the battery
c2=(Vm/Voc-1)/log(1-Im/Isc);
c1=(1-Im/Isc)*exp(-Vm/(c2*Voc));
Tf=25;             %% Set the reference temperature
%ta=0.002;
%Tc=25;
%T=sun*ta+Tc;
DT=T-Tf;      %% The difference between the actual temperature and the reference temperature
a=0.0004;     %% Reference sunshine (1kw / m2, 25 degree) current change temperature coefficient
b=-0.078;     %% Reference sunshine (1kw / m2, 25 degree) voltage change temperature coefficient
Rref=1000;    %% Reference radiation intensity 1kw / m2
N=6;          %% PV array modules
Np=2;
Ns=6;
x=1.12;       %% Material with energy
gvoc=-0.06;
gisc=2.0*10^(-3);
Aref=(T*gvoc-Voc+x*Ns)/((gisc*T/Isc)-3);
Rsref=(Aref*log(1-Im/Isc)-Vm+Voc)/Im;  %% The series resistance of the PV module in the reference state
Rs=N/Np*Rsref;                         %% Internal resistance of the battery
DI=a*sun/Rref*DT+(sun/Rref-1)*Isc;
Du=-b*DT-Rs*DI;
I=Isc*(1-c1*(exp((u-Du)/(c2*Voc))-1))+DI; %% Output current
