%
% File name:  micro_gas_turbine.m
% Contains:   Micro gas turbine output power and cost calculation
 
% gas_mt_1      =  65;  %MWh
% gas_mt_2      =  55;  %MWh
% gas_mt_3      =  45;  %MWh
% 1 cubic meter gas can produce 9.6-10.6 kWh. Here assumed 10 kWh.
function cost_MT = micro_gas_turbine(var)
MT1         = var(1);
MT2         = var(2);
MT3         = var(3);

heat=[121.0 123.0 124.0 122.0 125.0 117.0 114.0 106.0 97.0 90.0 86.0 78.0 62.0 57.0 62.0 74.0 98.0 114.0 137.0 154.0 150.0 150.0 144.0 140.0]; %,MWh
heat=(heat/max(heat))*60;%000;

gas_well_1_max =  13.800;%150; % Km^3/h 5300  % kcf/h
%gas_well_1_min =   .400; % Km^3/h
gas_well_2_max =  10.200; % Km^3/h 6000  % kcf/h
%gas_well_2_min =   .600; % Km^3/h
Gas_efficiency = .1; % Gas_efficiency_factor
 
gas_required_heat_load = heat*Gas_efficiency; % heat is household gas load
gas_available_for_mt   = (gas_well_1_max+gas_well_2_max)- gas_required_heat_load;
max_mt_produce         = gas_available_for_mt*6.35;
if max_mt_produce <= (MT1 + MT2 + MT3)-.1
    cost_MT = (MT1 + MT2 + MT3)*10;    % Total cost of three Micro turbine. 
else
    %-----------------Gas turbine Cost (MT)-----------------%
    d       = 0.1;
    %Gas turbine output model parameters
    LHVng   = 9.7;%Natural gas low calorific value
    Cng     = 2.05;%Natural gas price
    Kmt     = 0.128;
    a1      = 8;
    b1      = 0.2;
    a2      = 6;
    b2      = 0.0036;
    a3      = 0.023;
    b3      = 724;
    Lmt     = 10;
    InsCost3= 13060;
    %Pi3=65 = MT;
    cf3     = 0.5499;
    for MTi  = 1:3 %MT = [MT1 MT2 MT3]
        MT = var(MTi);
        %Gas turbine output power
        TMP = MT/65;  % Total capacity
        Nmt = 0.0753*TMP^3-0.3095*TMP^2+0.4174*TMP+0.4068;
        %Gas turbine fuel cost
        Vf  = MT/LHVng/Nmt;
        C1  = Cng*Vf;
        %Gas turbine maintenance cost
        OM3 = Kmt*MT;
        %Gas turbine pollutant treatment cost
        Cem1=(a1*b1+a2*b2+a3*b3)*MT/1000;
        %Gas turbine depreciation cost
        CFR3  = d*((1+d)^Lmt)/((1+d)^Lmt-1);
        ADCC3 = InsCost3*CFR3;
        Cdp3  = ADCC3*MT/66/8760/cf3+0.02*abs(MT-45);
        
        cost_MT(MTi) =C1 + OM3 + Cem1 + Cdp3;
    end
end